Documentation
¶
Overview ¶
Package testutils contains common functions for integration/load tests
Index ¶
Constants ¶
const ( Example32ByteKey = "HEREISA32CHARSECRETWHICHISMADEUP" Example64ByteKey = "HEREISA64CHARSECRETWHICHISMADEUPHEREISA64CHARSECRETWHICHISMADEUP" )
Variables ¶
This section is empty.
Functions ¶
func BuildArbitraryImage ¶
BuildArbitraryImage builds an image with a bunch of colors in it.
func BuildArbitraryImagePNGBytes ¶
BuildArbitraryImagePNGBytes builds an image with a bunch of colors in it.
Types ¶
This section is empty.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package containers provides shared helpers for starting testcontainers with uniform retry behavior.
|
Package containers provides shared helpers for starting testcontainers with uniform retry behavior. |
Click to show internal directories.
Click to hide internal directories.